==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/pt-PT/mail.php <==
<?php

return array(
    'a_user_canceled' => 'Um utilizador cancelou um pedido de artigo no site',
    'a_user_requested' => 'Um utilizador solicitou um artigo no site',
    'accessory_name' => 'Nome do acessório:',
    'additional_notes' => 'Notas adicionais:',
    'admin_has_created' => 'Um administrador criou uma conta para ti no :web site.',
    'asset' => 'Artigo:',
    'asset_name' => 'Nome do Artigo:',
    'asset_requested' => 'Artigo requesitado',
    'asset_tag' => 'Etiqueta de Artigo:',
    'assigned_to' => 'Atribuído a',
    'best_regards' => 'Atenciosamente',
    'canceled' => 'Cancelado:',
    'checkin_date' => 'Data de devolução:',
    'checkout_date' => 'Data de atribuição:',
    'click_to_confirm' => 'Por favor clique no link a seguir para confirmar sua conta :web:',
    'click_on_the_link_accessory' => 'Por favor clique no link na parte inferior para confirmar que recebeu o acessório.',
    'click_on_the_link_asset' => 'Por favor clique no link na parte inferior para confirmar que recebeu o artigo.',
    'Confirm_Asset_Checkin' => 'Asset checkin confirmation',
    'Confirm_Accessory_Checkin' => 'Accessory checkin confirmation',
    'Confirm_accessory_delivery' => 'Accessory delivery confirmation',
    'Confirm_license_delivery' => 'License delivery confirmation',
    'Confirm_asset_delivery' => 'Asset delivery confirmation',
    'Confirm_consumable_delivery' => 'Consumable delivery confirmation',
    'current_QTY' => 'qtde. actual',
    'Days' => 'Dias',
    'days' => 'Dias',
    'expecting_checkin_date' => 'Data prevista de devolução:',
    'expires' => 'Expira a',
    'Expiring_Assets_Report' => 'Relatório de artigos a expirar.',
    'Expiring_Licenses_Report' => 'Relatório de Licenças a expirar.',
    'hello' => 'Olá',
    'hi' => 'Oi',
    'i_have_read' => 'Li e concordo com os termos de uso e recebi este item.',
    'item' => 'Item:',
    'Item_Request_Canceled' => 'Requisição de item cancelado',
    'Item_Requested' => 'Item requisitado',
    'link_to_update_password' => 'Por favor clique no link abaixo para actualizar a sua senha do :web:',
    'login_first_admin' => 'Faça login na sua instalação do Snipe-IT usando os dados abaixo:',
    'login' => 'Login:',
    'Low_Inventory_Report' => 'Relatório de baixas de inventario',
    'min_QTY' => 'Qt. Min.',
    'name' => 'Nome',
    'new_item_checked' => 'Um novo item foi atribuído a ti, os detalhes estão abaixo.',
    'password' => 'Senha:',
    'password_reset' => 'Repor senha',

    'read_the_terms' => 'Por favor, leia os termos de uso abaixo.',
    'read_the_terms_and_click' => 'Por favor, leia os termos de uso abaixo e clique no link na parte inferior para confirmar que leu e que concorda com os termos de uso e ter recebido o artigo.',
    'requested' => 'Requisitado:',
    'reset_link' => 'Seu Link de redefinição da senha',
    'reset_password' => 'Clique aqui para redefinir a sua password:',
    'serial' => 'Nº de Série',
    'supplier' => 'Fornecedor',
    'tag' => 'Etiqueta',
    'test_email' => 'Email de teste do Snipe-IT',
    'test_mail_text' => 'Isto é um email de teste do Snipe-IT Asset Management System. Se recebeste o recebeste, quer dizer que o email está a funcionar :)',
    'the_following_item' => 'O Item a seguir foi devolvido: ',
    'low_inventory_alert' => 'Há :count que está abaixo do estoque mínimo ou em breve estará baixo. Existem :count itens que estão abaixo do estoque mínimo ou em breve estarão baixos.',
    'assets_warrantee_alert' => 'Há :count licença a expirar nos próximos :threshold dias. Existem :count licenças que irão expirar nos próximos :threshold dias.',
    'license_expiring_alert' => 'Há :count licença a expirar nos próximos :threshold dias. Existem :count licenças que irão expirar nos próximos :threshold dias.',
    'to_reset' => 'Para fazer reset a senha do :web, preencha este formulário:',
    'type' => 'Tipo',
    'upcoming-audits' => 'There is :count asset that is coming up for audit within :threshold days.|There are :count assets that are coming up for audit within :threshold days.',
    'user' => 'Utilizador',
    'username' => 'Nome de utilizador',
    'welcome' => 'Bem vindo, :name',
    'welcome_to' => 'Bem-vindo ao :web!',
    'your_credentials' => 'Suas credenciais do Snipe-IT',
    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'License_Checkin_Notification' => 'License checked in',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => 'View Your Assets'
);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/pt-PT/mail.php <==
<?php

return [
    'a_user_canceled' => 'Um utilizador cancelou um pedido de artigo no site',
    'a_user_requested' => 'Um utilizador solicitou um artigo no site',
    'accessory_name' => 'Nome do acessório:',
    'additional_notes' => 'Notas adicionais:',
    'admin_has_created' => 'Um administrador criou uma conta para ti no :web site.',
    'asset' => 'Artigo:',
    'asset_name' => 'Nome do Artigo:',
    'asset_requested' => 'Artigo requesitado',
    'asset_tag' => 'Etiqueta do Ativo',
    'assigned_to' => 'Atribuído a',
    'best_regards' => 'Atenciosamente',
    'canceled' => 'Cancelado:',
    'checkin_date' => 'Data de devolução:',
    'checkout_date' => 'Data de atribuição:',
    'click_to_confirm' => 'Por favor clique no link a seguir para confirmar sua conta :web:',
    'click_on_the_link_accessory' => 'Por favor clique no link na parte inferior para confirmar que recebeu o acessório.',
    'click_on_the_link_asset' => 'Por favor clique no link na parte inferior para confirmar que recebeu o artigo.',
    'Confirm_Asset_Checkin' => 'Confirmação da devolução do artigo',
    'Confirm_Accessory_Checkin' => 'Confirme a devolução do acessório',
    'Confirm_accessory_delivery' => 'Confirme a entrega do acessório',
    'Confirm_license_delivery' => 'Confirmação de entrega de licença',
    'Confirm_asset_delivery' => 'Confirmação de entrega do artigo',
    'Confirm_consumable_delivery' => 'Confirmação de entrega do consumível',
    'current_QTY' => 'qtde. actual',
    'Days' => 'Dias',
    'days' => 'Dias',
    'expecting_checkin_date' => 'Data prevista de devolução:',
    'expires' => 'Expira a',
    'Expiring_Assets_Report' => 'Relatório de artigos a expirar.',
    'Expiring_Licenses_Report' => 'Relatório de Licenças a expirar.',
    'hello' => 'Olá',
    'hi' => 'Oi',
    'i_have_read' => 'Li e concordo com os termos de uso e recebi este item.',
    'item' => 'Item:',
    'Item_Request_Canceled' => 'Requisição de item cancelado',
    'Item_Requested' => 'Item requisitado',
    'link_to_update_password' => 'Por favor clique no link abaixo para actualizar a sua senha do :web:',
    'login_first_admin' => 'Faça login na sua instalação do Snipe-IT usando os dados abaixo:',
    'login' => 'Login:',
    'Low_Inventory_Report' => 'Relatório de baixas de inventario',
    'min_QTY' => 'Qt. Min.',
    'name' => 'Nome',
    'new_item_checked' => 'Um novo item foi atribuído a ti, os detalhes estão abaixo.',
    'password' => 'Senha:',
    'password_reset' => 'Repor senha',

    'read_the_terms' => 'Por favor, leia os termos de uso abaixo.',
    'read_the_terms_and_click' => 'Por favor, leia os termos de uso abaixo e clique no link na parte inferior para confirmar que leu e que concorda com os termos de uso e ter recebido o artigo.',
    'requested' => 'Requisitado:',
    'reset_link' => 'Seu Link de redefinição da senha',
    'reset_password' => 'Clique aqui para redefinir a sua password:',
    'serial' => 'Nº de Série',
    'supplier' => 'Fornecedor',
    'tag' => 'Etiqueta',
    'test_email' => 'Email de teste do Snipe-IT',
    'test_mail_text' => 'Isto é um email de teste do Snipe-IT Asset Management System. Se recebeste o recebeste, quer dizer que o email está a funcionar :)',
    'the_following_item' => 'O Item a seguir foi devolvido: ',
    'low_inventory_alert' => 'Há :count que está abaixo do estoque mínimo ou em breve estará baixo. Existem :count itens que estão abaixo do estoque mínimo ou em breve estarão baixos.',
    'assets_warrantee_alert' => 'Existe :count artigo com a garantia a expirar nos próximos :threshold dias.|Existem :count artigos com a garantia a expirar nos próximos :threshold dias.',
    'license_expiring_alert' => 'Há :count licença a expirar nos próximos :threshold dias. Existem :count licenças que irão expirar nos próximos :threshold dias.',
    'to_reset' => 'Para fazer reset a senha do :web, preencha este formulário:',
    'type' => 'Tipo',
    'upcoming-audits' => 'Existe um :count ativo que está a chegar para ser auditado em :threshold dias.|Existem :count ativos que estão a chegar para serem auditados em :threshold dias.',
    'user' => 'Utilizador',
    'username' => 'Nome de utilizador',
    'welcome' => 'Bem vindo, :name',
    'welcome_to' => 'Bem-vindo ao :web!',
    'your_credentials' => 'Suas credenciais do Snipe-IT',
    'Accessory_Checkin_Notification' => 'Accessory checked in',
    'Asset_Checkin_Notification' => 'Asset checked in',
    'License_Checkin_Notification' => 'License checked in',
    'Expected_Checkin_Report' => 'Expected asset checkin report',
    'Expected_Checkin_Notification' => 'Reminder: :name checkin deadline approaching',
    'Expected_Checkin_Date' => 'An asset checked out to you is due to be checked back in on :date',
    'your_assets' => 'Ver seus ativos',
];
